<?php

	/* Get option as string or array */
	function gridfx_get_option($option){
		global $gridfx_admin;
		$options = get_option('gridfx');
		if (isset($options[$option])) {
			return $options[$option];
		} else {
			return $gridfx_admin->defaults[$option];
		}
	}
	
	/* Get option as string always */
	function gridfx_get_option_string($option, $gridfx_opts){
		global $gridfx_admin;
		if (isset($gridfx_opts[$option])) {
			$response = $gridfx_opts[$option];
		} else {
			$response = $gridfx_admin->defaults[$option];
		}
		if ($response) {
			if (is_array($response)) {
				return implode(',',$response);
			} else {
				return $response;
			}
		}
	}
	
	/* List all values */
	function gridfx_list_files($loc, $extension = 'php') {
		$array = null;
		foreach (glob(gridfx_path . $loc . "/*.$extension", GLOB_BRACE) as $filename) {
			$clean = str_replace(".$extension","", basename($filename) );
			$array[$clean] = $clean;
		}
		return $array;
	}
	
	/* List yes/no as array */
	function gridfx_list_yes_or_no() {
		return array(
					1 => __('Yes','gridfx'),
					0 => __('No','gridfx')
				);
	}
	
	/* List show/hide as array */
	function gridfx_list_show_hide() {
		return array(
					'show' => __('Show','gridfx'),
					'hide' => __('Hide','gridfx')
				);
	}
	
	/* List scrollbar themes */
	function gridfx_list_scrollbar_themes(){
		return array(
					'light' => __('light','gridfx'),
					'light-2' => __('light-2','gridfx'),
					'light-thick' => __('light-thick','gridfx'),
					'light-thin' => __('light-thin','gridfx'),
					'dark' => __('dark','gridfx'),
					'dark-2' => __('dark-2','gridfx'),
					'dark-thick' => __('dark-thick','gridfx'),
					'dark-thin' => __('dark-thin','gridfx'),
				);
	}
	
	/* List cat order options */
	function gridfx_list_cat_order(){
		return array(
					'id' => __('ID','gridfx'),
					'count' => __('Count','gridfx'),
					'name' => __('Name','gridfx'),
					'slug' => __('Slug','gridfx')
				);
	}
	
	/* List post available order */
	function gridfx_list_post_order(){
		return array(
					'ID' => __('ID','gridfx'),
					'date' => __('Date','gridfx'),
					'title' => __('Title','gridfx'),
					'name' => __('Post Slug','gridfx'),
					'modified' => __('Last Modified','gridfx'),
					'comment_count' => __('Comment Count','gridfx') ,
					'meta_value_num'	=> 'Sort By Meta Key'
				);
	}
	
	
	/* List allowed fonts */
	function gridfx_list_fonts() {
		return array(
					'Arial' => 'Arial',
					'Open Sans' => 'Open Sans',
					'Oswald' => 'Oswald',
					'Tahoma' => 'Tahoma',
					'Georgia' => 'Georgia',
					'Verdana' => 'Verdana'
				);
	}
	
	/* List post types */
	function gridfx_list_post_types(){
		$types = get_post_types( array('public' => true) , 'objects');
		foreach($types as $type){
			$array[$type->name] = $type->labels->singular_name;
		}
		return $array;
	}
	
	/* List woo taxonomies */
	function gridfx_list_taxonomies_woo($multi=0){
		$array = array();
		$taxonomies = array('product_cat','product_tag');
		if ($multi == 0) $array[0] = __('Disable Category Filter Dropdown','gridfx');
		foreach ($taxonomies as $taxonomy ) {
			if (taxonomy_exists($taxonomy)){
			$the_tax = get_taxonomy( $taxonomy );
			$array[$taxonomy] = $the_tax->labels->name;
			}
		}
		return $array;
	}
	
	/* List taxonomies */
	function gridfx_list_taxonomies($multi=0){
		$taxonomies=get_taxonomies( array('public' => true), 'names');
		if ($multi == 0) $array[0] = __('Disable Category Filter Dropdown','gridfx');
		foreach ($taxonomies as $taxonomy ) {
			$the_tax = get_taxonomy( $taxonomy );
			$array[$taxonomy] = $the_tax->labels->name;
		}
		return $array;
	}
	
	/* List cateogries as parents */
	function gridfx_list_categories_parents(){
		$taxonomies=get_taxonomies( array('public' => true), 'names');
		foreach ($taxonomies as $taxonomy ) {
			$the_tax = get_taxonomy( $taxonomy );
			$terms = get_terms( $taxonomy , array('hide_empty' => 0));
			if ($terms) {
				$array["optgroup_b_{$taxonomy}"] = $the_tax->labels->name;
				foreach($terms as $term) {
					$children = get_term_children( $term->term_id, $taxonomy ); // get parent categories only (top-level)
					if (!empty($children)) {
						$array[$term->term_id] = $term->name;
					}
				}
				$array["optgroup_e_{$taxonomy}"] = $the_tax->labels->name;
			}
		}
		return $array;
	}
	
	/* List all categories */
	function gridfx_list_categories_all(){
		$taxonomies=get_taxonomies( array('public' => true) , 'names');
		foreach ($taxonomies as $taxonomy ) {
			if (!in_array($taxonomy, gridfx_hidden_taxonomies())) {
			$the_tax = get_taxonomy( $taxonomy );
			$terms = get_terms( $taxonomy , array('hide_empty' => 0));
			if ($terms) {
				$array["optgroup_b_{$taxonomy}"] = $the_tax->labels->name;
				foreach($terms as $term) {
						$array[$term->term_id] = $term->name;
				}
				$array["optgroup_e_{$taxonomy}"] = $the_tax->labels->name;
			}
			}
		}
		return $array;
	}
	
	/* Hidden taxonomies won't show up */
	function gridfx_hidden_taxonomies(){
		return array(
			'shop_order_status',
			'product_type'
		);
	}
	
	function gridfx_update_installed($update) {
		if(!get_option('gridfx_update_'.$update)) {
			update_option('gridfx_update_'.$update , '1');
			return false;
		}else {
			return true;
		}
	}
	
	add_action('admin_notices' , 'gridfx_admin_notice');
	
	function gridfx_admin_notice() {
		if(isset($_GET['page']) && $_GET['page'] == 'gridfx') {
		echo '<div class="">
               <h1>Envato Purchase Code</h1>
  					<form action="" method="post">
					    <input type="text" value="'.get_option('gridfx-envato-code').'" name="gridfx-envato-code" placeholder="Envato Purchase Code">
					    <input type="submit" name="verify" class="button button-primary" value="Verify">
  					</form>
				</div>';
		}
	}
	
	add_action('admin_init', 'gridfx_process_envato_verify');
	
	function gridfx_process_envato_verify() {
		if(isset($_POST['verify']) && $_POST['gridfx-envato-code']) {
			update_option('gridfx-envato-code', $_POST['gridfx-envato-code']);
		}
	}