<?php

class gridfx_admin {

	var $options;

	function __construct() {
	
		/* Plugin slug and version */
		$this->slug = 'gridfx';
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		$this->plugin_data = get_plugin_data( gridfx_path . 'index.php', false, false);
		$this->version = $this->plugin_data['Version'];
		
		/* Priority actions */
		add_action('admin_menu', array(&$this, 'add_menu'), 9);
		add_action('admin_enqueue_scripts', array(&$this, 'add_styles'), 9);
		add_action('admin_head', array(&$this, 'admin_head'), 9 );
		add_action('admin_init', array(&$this, 'admin_init'), 9);
		
	}
	
	function admin_init() {
	
		$this->tabs = array(
			'settings' => __('Settings','gridfx'),
			'generate' => __('Generate','gridfx'),
			'docs' => __('Docs','gridfx'),
			'updates' => __('Updates','gridfx')
		);
		$this->default_tab = 'settings';

		$this->fields_sections = array(
			'general' => array('name' => __('General','gridfx') ),
			'layout' => array('name' => __('Layout','gridfx') ),
			'loop' => array('name' => __('Loop and Pagination','gridfx') ),
			'media' => array('name' => __('Media','gridfx') ),
			'grid' => array('name' => __('Grid View','gridfx') ),
			'single' => array('name' => __('Single View','gridfx') ),
			'lightbox' => array('name' => __('Lightbox','gridfx') ),
			'misc' => array('name' => __('Misc','gridfx') ),
			'woo' => array('name' => __('WooCommerce','gridfx') )
		);
		
		$this->fields['general'] = array(
			'title' => array('type' => 'text', 'name' => __('Title','gridfx'), 'help' =>  __('Optionally display a title that describes your wall.','gridfx'), 'default' => '', 'doc' => __('This is an optional parameter that lets you display a custom heading or title for your grid wall.','gridfx') ),
			'description' => array('type' => 'textarea', 'name' => __('Optional Description','gridfx'), 'default' => '', 'doc' => __('This is an optional parameter that lets you display a custom description below the title for your grid wall. You can use both text and HTML in this field.','gridfx') ),
			'theme' => array('type' => 'select', 'name' => __('Theme','gridfx'), 'values' => gridfx_list_files('templates/themes'), 'default' => 'light', 'doc' => __('General theme to use, themes are located in /templates/themes folder. e.g. light or dark, etc.','gridfx') ),
			'default_theme' => array('type' => 'select', 'name' => __('Default Theme','gridfx'), 'values' => gridfx_list_files('templates/themes'), 'default' => 'light', 'doc' => __('Default theme fallback to use. The plugin will use this theme if the <strong>theme</strong> does not exist.','gridfx') ),
'users_dropdown' => array('type' => 'select', 'name' => __('Users Dropdown','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('','gridfx'), 'default' => 1, 'doc' => __('','gridfx') ),
			'transparent' => array('type' => 'select', 'name' => __('Match Theme Background','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('Enable this option If you want to apply transparent background to your Grid FX grid to match your theme or parent background. Enabling this option will override Grid FX style background.','gridfx'), 'default' => 0, 'doc' => __('Enable this option If you want to apply transparent background to your Grid FX grid to match your theme or parent background. Enabling this option will override Grid FX style background.','gridfx') ),
			'primary_font' => array('type' => 'select', 'name' => __('Primary Font','gridfx'), 'values' => gridfx_list_fonts(), 'default' => 'Open Sans', 'doc' => __('Font to use in the plugin. You can see list of available fonts in the settings/generate pages.','gridfx') ),
			'custom_css' => array('type' => 'textarea', 'name' => __('Custom CSS<span>(any css rules here will apply to .gridfx container)</span>','gridfx'), 'default' => '', 'doc' => __('Custom css rules that apply to the .gridfx container. You can add custom styles that will affect only the shortcode being shown. e.g. a special border, background, or any other css rule.','gridfx') ),
			'margin' => array('type' => 'text', 'name' => __('Override top margin','gridfx'), 'help' =>  __('This value controls the top margin above Grid FX items in pixels.','gridfx'), 'default' => 30, 'doc' => __('This value controls the top margin above Grid FX items in pixels.','gridfx') ),
		);
		
		$this->fields['layout'] = array(
			'crop' => array('type' => 'select', 'name' => __('Force Images to be Equal Height','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('Enable this option If your images have different dimensions and you want to apply the same height/crop all images to make them equal.','gridfx'), 'default' => 0, 'doc' => __('Set this to 1 If your images have different dimensions and you want to apply the same height/crop all images to make them equal.','gridfx') ),
			'crop_quickmode' => array('type' => 'select', 'name' => __('Apply crop to quick/full view too?','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('If you enable this, cropped image will be also used in quick mode. Turn off to make crop in grid items only (not quick view).','gridfx'), 'default' => 0, 'doc' => __('If you enable this, cropped image will be also used in quick mode. Turn off to make crop in grid items only (not quick view).','gridfx') ),
			'crop_width' => array('type' => 'text', 'name' => __('Cropped Image Width','gridfx'), 'help' =>  __('If you enable the equal height/cropping, please enter the standard width of image here.','gridfx'), 'default' => 500, 'doc' => __('If you enable the equal height/cropping, please enter the standard width of image here.','gridfx') ),
			'crop_height' => array('type' => 'text', 'name' => __('Cropped Image Height','gridfx'), 'help' =>  __('If you enable the equal height/cropping, please enter the standard height of image here.','gridfx'), 'default' => 281, 'doc' => __('If you enable the equal height/cropping, please enter the standard width of image here.','gridfx') ),
			'crop_pos' => array('type' => 'select', 'name' => __('Image Cropping Position','gridfx'),
				'values' => array('t' => __('crop towards top','gridfx'), 'c' => __('crop towards center','gridfx'),'b' => __('crop towards bottom','gridfx') ), 'default' => 't' , 'doc' => __('Enter your crop position here If you enable the crop option (equal image heights). The accepted value can be: t (Top) c (Center) b (Bottom)','gridfx') ),
			'columns' => array('type' => 'text', 'name' => __('No. of Columns','gridfx'), 'help' =>  __('Enter number of default columns to display. This can be ignored in smaller screens.','gridfx'), 'default' => 3, 'doc' => __('The number of columns to show by default in the grid. This number should be logical and relative to the parent or window width, depending on screen/document width this number can be ignored in responsive mode.','gridfx') ),
			'items_container_width' => array('type' => 'text', 'name' => __('Items Container Width (%)','gridfx'), 'help' =>  __('Width of the container that contains items. By default, it expands to 100% of the available or parent width.','gridfx'), 'default' => 100, 'doc' => __('The percentage width of the container that holds the items, not the width of whole Grid FX instance. This is useful if you want to leave gaps on the left and right of items.','gridfx') ),
			'image_max_width' => array('type' => 'text', 'name' => __('Maximum Width for Image (%)','gridfx'), 'help' =>  __('The maximum width image can have in full view mode, when no content is shown.','gridfx'), 'default' => 100, 'doc' => __('This is the maximum percentage width an image can have in full/single mode.','gridfx') ),
			'item_content_width' => array('type' => 'text', 'name' => __('Container Width in Full View (%)','gridfx'), 'help' =>  __('Width of single item / full mode view.','gridfx'), 'default' => 70, 'doc' => __('This is the percentage width of full/single mode relative to its parent.','gridfx') ),
			'item_content_left_width' => array('type' => 'text', 'name' => __('Left Side Width in Full View (%)','gridfx'), 'help' => __('This is applicable when content is available in full view.','gridfx'), 'default' => 50, 'doc' => __('This is the percentage width of the left side in full mode and when content is available. e.g. Width of post image. Remember width of left and right containers must not exceed 100.','gridfx') ),
			'item_content_right_width' => array('type' => 'text', 'name' => __('Right Side Width in Full View (%)','gridfx'), 'help' =>  __('This is applicable when content is available in full view.','gridfx'), 'default' => 45, 'doc' => __('This is the percentage width of the right side in full mode and when content is available e.g. Width of post content. Remember width of left and right containers must not exceed 100.','gridfx') ),
		);
		
		$this->fields['loop'] = array(
			'instantsearch' => array('type' => 'select', 'name' => __('Enable Search Feature','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('This option can enable or disable instant search feature in your grid. The value can be 1 or 0.','gridfx') ),
			'search_placeholder' => array('type' => 'text', 'name' => __('Search Placeholder','gridfx'), 'default' => __('Search','gridfx'), 'doc' => __('Set the default search placeholder if you enabled search feature.','gridfx') ),
			'integrate' => array('type' => 'select', 'name' => __('Out of box Integration','gridfx'), 'values' => array( 0 => __('None','gridfx'), 'woocommerce' => __('WooCommerce','gridfx') ), 'help' => __('The plugin offers integration with specific WordPress platforms. Note that this integration may override other options such as post type, taxonomies, and other template options.','gridfx'), 'default' => 0, 'doc' => __('The plugin offers integration with specific WordPress platforms. Note that this integration may override other options such as post type, taxonomies, and other template options. example: to integrate with WooCommerce instantly, enter woocommerce here.','gridfx') ),
			'posttypes' => array('type' => 'multiselect', 'name' => __('Include Post Types','gridfx'), 'values' => gridfx_list_post_types(), 'placeholder' => __('Select post type(s)...','gridfx'), 'default' => 'post', 'doc' => __('A comma seperated of allowed post types in the grid. This can be a single post type also. examples: post,page or attachment','gridfx') ),
			'sortmenu' => array('type' => 'select', 'name' => __('Show Sort Results Menu','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('This option can show or hide the sort results by dropdown where frontend users can sort the results by various ways.','gridfx') ),
			'taxonomy_filter' => array('type' => 'multiselect', 'name' => __('Setup Taxonomy/Category Filters','gridfx'), 'values' => gridfx_list_taxonomies(1), 'placeholder' => __('Select taxonomies','gridfx'), 'help' => __('This will enable these taxonomies to display filterable dropdowns above grid.','gridfx'), 'default' => 'category', 'doc' => __('This can be a comma seperated list of taxonomies that you want to allow users to filter on the frontend. examples: category or category,post_tag, etc. This will display a list of these categories that user can filter by.','gridfx') ),
			'hide_empty_cat' => array('type' => 'select', 'name' => __('Hide empty categories from nav','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('This option can hide/show empty categories from navigation. This option can be 1 or 0.','gridfx') ),
			'cat_list_orderby' => array('type' => 'select', 'name' => __('Order Category Listing by','gridfx'), 'values' => gridfx_list_cat_order(), 'default' => 'name', 'doc' => __('Order of categories in the nav if you enable isotope filtering. This can be name, id, slug, or count.','gridfx') ),
			'posts_per_page' => array('type' => 'text', 'name' => __('Posts per Page','gridfx'), 'help' => __('Number of posts to show on wall page. Leave blank to display all posts in one page.','gridfx'), 'default' => 9, 'doc' => __('Number of posts to show per page in the grid. To show all posts and disable pagination please use -1 as value to display all items.','gridfx') ),
			'orderby' => array('type' => 'select', 'name' => __('Sort Posts by','gridfx'), 'values' => gridfx_list_post_order(), 'default' => 'date', 'doc' => __('This can control the order/sorting of posts and results in your grid. Accepted values are: date, title, name, ID, modified, comment_count','gridfx') ),
			'order' => array('type' => 'select', 'name' => __('Sort Order','gridfx'), 'values' => array( 'DESC' => 'DESC', 'ASC' => 'ASC' ), 'default' => 'DESC', 'doc' => __('This will control the sorting order. This can be DESC or ASC.','gridfx') ),
			'include_terms_tree' => array('type' => 'multiselect', 'name' => __('Include specific parent categories','gridfx'), 'values' => gridfx_list_categories_parents(), 'placeholder' => __('Select categories...','gridfx'), 'default' => 0, 'doc' => __('This can be a comma seperated list of parent categories IDs to include in the results. examples: 1,4,10. This will include the specified parent categories and their children categories in results.','gridfx') ),
			'include_terms' => array('type' => 'multiselect', 'name' => __('Include specific categories','gridfx'), 'values' => gridfx_list_categories_all(), 'placeholder' => __('Select categories...','gridfx'), 'default' => 0, 'doc' => __('This can be a comma seperated list of children categories IDs to include in the results. examples: 1,4,10. This will include only the specified categories in results.','gridfx') ),
			'exclude_terms_tree' => array('type' => 'multiselect', 'name' => __('Exclude specific parent categories','gridfx'), 'values' => gridfx_list_categories_parents(), 'placeholder' => __('Select categories...','gridfx'), 'default' => 0, 'doc' => __('This can be a comma seperated list of parent categories IDs to exclude from the results. examples: 8,12,22. This will exclude the specified parent categories and their children categories from results.','gridfx') ),
			'exclude_terms' => array('type' => 'multiselect', 'name' => __('Exclude specific categories','gridfx'), 'values' => gridfx_list_categories_all(), 'placeholder' => __('Select categories...','gridfx'), 'default' => 0, 'doc' => __('This can be a comma seperated list of children categories IDs to exclude from the results. examples: 8,12,22. This will exclude only the specified categories from results.','gridfx') ),
			'paged' => array('type' => 'text', 'name' => __('Default Page Number','gridfx'), 'help' => __('Enter page number to show by default initially.','gridfx'), 'default' => 1, 'doc' => __('This is the default page to display. It does not have effect when you display all items.','gridfx') ),
			'post_parent' => array('type' => 'text', 'name' => __('Limit to Post Parent','gridfx'), 'help' => __('For example, If you want to display images in a specific post as a gallery/grid, enter the parent post ID here or leave blank.','gridfx'), 'default' => '', 'doc' => __('If you want to display images from a specific post as a gallery for example, enter the parent post ID here. Leave blank to disable.','gridfx') ),
			'load_more' => array('type' => 'select', 'name' => __('Load More Method','gridfx'),
				'values' => array('button' => __('Load More Button','gridfx'),'navigation' => __('Next/Previous Arrow Navigation','gridfx'),'pagination' => __('Pagination','gridfx'),'full' => __('Pagination & Arrows','gridfx'), 0 => __('Disable','gridfx') ), 'help' =>  __('If you enable loading more content, you can select which method to load more items here.','gridfx'), 'default' => 'button', 'doc' => __('This option specify how you want loading more content to be handled. Possible values: button, pagination, navigation, full, or 0 to disable loading more items.','gridfx') ),
			'load_more_text' => array('type' => 'text', 'name' => __('Load More Button Text','gridfx'), 'help' => __('Applicable to loading content via button only.','gridfx'), 'default' => __('Load more','gridfx'), 'doc' => __('The text that is shown on the button that loads more posts. examples: Load more themes.','gridfx') ),
			'loaded_all_text' => array('type' => 'text', 'name' => __('Loaded All Content Text','gridfx'), 'help' => __('Applicable to loading content via button only.','gridfx'), 'default' => __('Loaded all content','gridfx'), 'doc' => __('The text that is shown on the button after loading all items. examples: Loaded all content.','gridfx') ),
			'load_more_img' => array('type' => 'text', 'name' => __('Loading More Image','gridfx'), 'help' => __('Enter the URL of loading image that appears on the button while loading is done.','gridfx'), 'default' => gridfx_url . 'images/loading-more.png', 'doc' => __('This is the path/URL of your loading spinner/image that get shown on the load more button until new results are loaded.','gridfx') ),
		);
	
		$this->fields['media'] = array(
			'enable_grid_media' => array('type' => 'select', 'name' => __('Enable Media in Grid/Gallery','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('Enable or disable media in grid gallery. Allow media in the grid too.','gridfx') ),
		);
		
		$this->fields['grid'] = array(
			'global_image_action' => array('type' => 'select', 'name' => __('On Clicking Grid Image','gridfx'), 'values' => array( 0 => __('Default','gridfx'), 'open_fancybox' => __('Open Fancybox Image','gridfx'), 'post_url' => __('Go to Post URL','gridfx') ), 'help' => __('When image in grid is clicked what action is taken.','gridfx'), 'default' => 0, 'doc' => __('Here you can modify the action that happens on image click. Default is 0 and available values are open_fancybox or post_url to open post directly.','gridfx') ),
			'link_to_post' => array('type' => 'select', 'name' => __('Link to Post Permalink','gridfx'), 'values' => array( 0 => __('No link by default','gridfx'), 1 => __('Place a button below item image','gridfx'), 2 => __('Place a button over the item image','gridfx'), 3 => __('Place a little icon over the image','gridfx'), 4 => __('Make the whole image link to post','gridfx'), 5 => __('Make the more details icon link to post','gridfx') ), 'help' => __('If you want to force link to post without messing up with custom template/buttons option please choose an appropriate option here.','gridfx'), 'default' => 0, 'doc' => __('If you want to force link to post without messing up with custom template/buttons option please choose an appropriate option here.','gridfx') ),
			'link_to_post_text' => array('type' => 'text', 'name' => __('Link to Post Icon Text','gridfx'), 'help' => __('If you choose to place the little icon over image to link to post, this is the text that will appear besides the icon. example: continue or full post.','gridfx'), 'default' => __('full post','gridfx'), 'doc' => __('If you choose to place the little icon over image to link to post, this is the text that will appear besides the icon. example: continue or full post.','gridfx') ),
			'show_title' => array('type' => 'select', 'name' => __('Show Title','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('Some Grid FX skins MAY not support this.','gridfx'), 'default' => 1, 'doc' => __('This can show or hide the post title display below the item image in grid view. This option may not be supported by specific Grid FX themes.','gridfx') ),
			'pre_title' => array('type' => 'text', 'name' => __('Pre Title Word','gridfx'), 'help' => __('Prefix all items titles in the gallery or grid display with this word. e.g. Theme:','gridfx'), 'default' => '', 'doc' => __('This can be optional prefix that gets shown before every title. For example If you are showing products, you can set this to Product:','gridfx') ),
			'excerpt_below_title' => array('type' => 'text', 'name' => __('Excerpt below Title','gridfx'), 'help' => __('Enter number of words to display an excerpt below title. Leave blank to disable this excerpt.','gridfx'), 'default' => '', 'doc' => __('Enter number of words to display an excerpt below title. Leave blank to disable this excerpt.','gridfx') ),
			'excerpt_over_image' => array('type' => 'text', 'name' => __('Excerpt over Image','gridfx'), 'help' => __('Enter number of words to display an excerpt over image. Leave blank to disable this excerpt.','gridfx'), 'default' => '', 'doc' => __('Enter number of words to display an excerpt over image. Leave blank to disable this excerpt.','gridfx') ),
			'tags_filter' => array('type' => 'multiselect', 'name' => __('Show list of post terms<span>Some Grid FX skins MAY not support this.</span>','gridfx'), 'values' => gridfx_list_taxonomies(1), 'placeholder' => __('Select taxonomies','gridfx'), 'default' => 'post_tag', 'doc' => __('This can be a comma seperated list of taxonomies to display post terms for each item in the grid. examples: post_tag or post_tag,category, etc. This will display a list of post terms/categories and enable isotope filtering automatically. This option may not be supported by specific Grid FX themes.','gridfx') ),
			'item_custom_field' => array('type' => 'text', 'name' => __('Custom field meta besides title','gridfx'), 'help' => __('To display a custom field data besides the title, leave blank to disable. Some Grid FX skins MAY not support this.','gridfx'), 'default' => '', 'doc' => __('This can be a custom meta key that displays data besides the title such as price, or any other meta data needed. Leave blank to disable. This option may not be supported by specific Grid FX themes.','gridfx') ),
			'item_custom_field_filter' => array('type' => 'select', 'name' => __('Apply specific filter to custom field data','gridfx'), 'values' => array(0 => __('None','gridfx'), 'euro' => __('Euro number format','gridfx'), 'dollar' => __('Dollar number format','gridfx'), 'plain' => __('Number format without currency','gridfx') ), 'default' => 0, 'doc' => __('If you store prices like this 1200 and want to apply automated filter or some sort of number format like converting the number to euro or US dollar format.','gridfx') ),
			'show_views' => array('type' => 'select', 'name' => __('Enable views on overlay','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('Enable views count in grid/overlay view. This option can be 1 or 0.','gridfx') ),
			'show_likes' => array('type' => 'select', 'name' => __('Enable likes on overlay','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('Enable likes in grid/overlay view. This option can be 1 or 0.','gridfx') ),
			'show_comments' => array('type' => 'select', 'name' => __('Enable comments on overlay','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('Comments are not yet integrated in Grid FX plugin. Please leave this disabled and watch for plugin updates.','gridfx') ),
			'show_corner' => array('type' => 'select', 'name' => __('Enable the display of custom field data in top right corner','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('For example, to display price, special word or anything else as a tag/corner in the gallery item.','gridfx'), 'default' => 0, 'doc' => __('Enable or disable the display of a custom field value in the top right corner over grid item image in grid mode.','gridfx') ),
			'show_corner_key' => array('type' => 'text', 'name' => __('Right Corner Custom Field','gridfx'), 'help' => __('If you allow the above option, please set the custom field to display here. e.g. price','gridfx'), 'default' => '', 'doc' => __('If you enable the above option, enter the meta field key here to grab the value from. This can be useful to show any specific meta field value.','gridfx') ),
			'show_overlay_title_v2' => array('type' => 'select', 'name' => __('Enable title (v2) on overlay','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('This is an extra overlay style. Enabling this title may remove other controls on overlay because it is centered in the image and gives a simple look.','gridfx'), 'default' => 0, 'doc' => __('This is an extra overlay style. Enabling this title may remove other controls on overlay because it is centered in the image and gives a simple look.','gridfx') ),
			'show_overlay_title' => array('type' => 'select', 'name' => __('Enable title on overlay','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('Enable or disable title on item overlay in grid view. If enabled, the post title will be displayed on top of the overlay.','gridfx') ),
			'show_overlay_title_class' => array('type' => 'radio', 'name' => __('Overlay title animation','gridfx'),
				'values' => array('none' => __('none','gridfx'),'top' => __('animate from top','gridfx')), 'help' => __('If you enable title display on the overlay, you can choose animation here.','gridfx'), 'default' => 'top', 'doc' => __('If you enable the above option, you can enter one of these values: none or top. none will show the title in static style over the item image, while top will animate the title from top to bottom when you move the mouse over the item image in grid mode.','gridfx') ),
			'overlay_title_css' => array('type' => 'textarea', 'name' => __('Overlay title custom css','gridfx'), 'default' => '', 'doc' => __('Custom css rules that apply to the overlay title which shows up on grid If enabled.','gridfx') ),
			'shadow_layer' => array('type' => 'select', 'name' => __('Show/hide the shadow layer on each item','gridfx'), 'values' => gridfx_list_show_hide(), 'default' => 'hide', 'doc' => __('Hide or show the shadow layer over your grid items. This option can be 1 or 0.','gridfx') ),
			'transparent_layer' => array('type' => 'select', 'name' => __('Show/hide the transparent layer on each item','gridfx'), 'values' => gridfx_list_show_hide(), 'default' => 'hide', 'doc' => __('Hide or show the transparent layer over your grid items. This option can be 1 or 0.','gridfx') ),
			'overlay_lightbox_text' => array('type' => 'select', 'name' => __('Enable fancybox/lightbox photos on each item','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1 , 'doc' => __('This enable or disable the fancybox photos trigger on each grid item overlay. This can be 1 or 0.','gridfx') ),
			'photos_label' => array('type' => 'text', 'name' => __('"Photos" Plural Word','gridfx'), 'help' => __('If you enable fancybox photos for each item, this is the text that describes the photos in plural form. e.g. photos','gridfx'), 'default' => __('photos','gridfx'), 'doc' => __('This controls the word that describes photos in plural form. examples: photos, screenshots, pictures.','gridfx') ),
			'photos_label_singular' => array('type' => 'text', 'name' => __('"Photos" Singular Word','gridfx'), 'help' => __('If you enable fancybox photos for each item, this is the text that describes the photos in singular form. e.g. photo','gridfx'), 'default' => __('photo','gridfx'), 'doc' => __('This controls the word that describes photos in singular form. examples: photo, screenshot, picture.','gridfx') ),
			'more_details_text' => array('type' => 'text', 'name' => __('"Quick View" Word','gridfx'), 'help' => __('The word that appears on overlay to open full view, leave blank to disable.','gridfx'), 'default' => __('quick view','gridfx'), 'doc' => __('This is the text that is shown on grid item overlay to expand view. Leave blank to disable this behaviour.','gridfx') ),
			'item_links' => array('type' => 'text', 'name' => __('Custom Buttons Template on the overlay','gridfx'), 'help' => __('You can show custom buttons template using special syntax. Please refer to the <a href="?page=gridfx&tab=docs">help</a> for examples.','gridfx'), 'default' => '', 'doc' => __('This is optional. You can use this option to display buttons on the image in grid view e.g. Live Demo, Buy Now, etc. This template needs to have a special syntax and format. example: meta_key or URL|Button Text|Button Style. Please check out the FAQs on top to learn about available buttons styles.','gridfx') ),
			'item_extended_links' => array('type' => 'text', 'name' => __('Custom Buttons Template below overlay<span>Some Grid FX skins MAY not support this.</span>','gridfx'), 'help' => __('You can show custom buttons template using special syntax. Please refer to the <a href="?page=gridfx&tab=docs">help</a> for examples.','gridfx'), 'default' => '', 'doc' => __('Custom extended links may NOT be supported by all Grid FX themes. This is optional. You can use this option to display buttons below item image in grid mode. e.g. Live Demo, Buy Now, etc. This template needs to have a special syntax and format. example: meta_key or URL|Button Text|Button Style. Please check out the FAQs on top to learn about available buttons styles.','gridfx') ),
		);
		
		$this->fields['single'] = array(
			'single_theme' => array('type' => 'select', 'name' => __('Single Item Theme','gridfx'), 'values' => gridfx_list_files('templates/themes/single'), 'default' => 'dark', 'doc' => __('Theme to use in single/expanded view, themes are located in /templates/themes/single folder. e.g. light or dark, etc.','gridfx') ),
			'default_single_theme' => array('type' => 'select', 'name' => __('Default Theme for Single Item','gridfx'), 'values' => gridfx_list_files('templates/themes/single'), 'default' => 'dark', 'doc' => __('Default theme fallback to use in single view. The plugin will use this theme if the <strong>single_theme</strong> does not exist.','gridfx') ),
			'scrollbar_theme' => array('type' => 'select', 'name' => __('Custom Scrollbar Theme','gridfx'), 'values' => gridfx_list_scrollbar_themes(), 'default' => 'light-thick', 'doc' => __('This is the theme name that controls the appearance of custom scrollbar in single view to navigate post content. This can be: light-thick, light, light-2, light-thin, dark-thick, dark, dark-2, dark-thin.','gridfx') ),
			'single_show_content' => array('type' => 'select', 'name' => __('Enable content display in full view','gridfx'), 'help' => __('When a post already has content available. You can switch off content entirely here.','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('This enable or disable post content in full view even a post has content available. You can turn off contents completely by turning this to 0.','gridfx') ),
			'single_hide_image' => array('type' => 'select', 'name' => __('Hide Image in Quick View','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('This enable or disable post image in full view.','gridfx') ),
			'single_show_views' => array('type' => 'select', 'name' => __('Enable views in full view','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('Enable views count in full view. This option can be 1 or 0.','gridfx') ),
			'single_show_likes' => array('type' => 'select', 'name' => __('Enable likes in full view','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('Enable likes in full view. This option can be 1 or 0.','gridfx') ),
			'single_show_comments' => array('type' => 'select', 'name' => __('Enable comments in full view','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('Comments are not yet integrated in Grid FX plugin. Please leave this disabled and watch for plugin updates.','gridfx') ),
			'single_show_corner' => array('type' => 'select', 'name' => __('Enable the display of custom field data in top right corner','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('For example, to display price, special word or anything else as a tag/corner in the gallery item.','gridfx'), 'default' => 0, 'doc' => __('Enable or disable the display of a custom field value in the top right corner of image in full mode.','gridfx') ),
			'single_show_corner_key' => array('type' => 'text', 'name' => __('Right Corner Custom Field','gridfx'), 'help' => __('If you allow the above option, please set the custom field to display here. e.g. price','gridfx'), 'default' => '', 'doc' => __('If you enable the above option, enter the meta field key here to grab the value from. This can be useful to show any specific meta field value.','gridfx') ),
			'single_item_links' => array('type' => 'text', 'name' => __('Custom Buttons Template in full view','gridfx'), 'help' => __('You can show custom buttons template using special syntax. Please refer to the <a href="?page=gridfx&tab=docs">help</a> for examples.','gridfx'), 'default' => '', 'doc' => __('This is optional. You can use this option to display buttons on the image in expanded view e.g. Live Demo, Buy Now, etc. This template needs to have a special syntax and format. example: meta_key or URL|Button Text|Button Style. Please check out the FAQs on top to learn about available buttons styles.','gridfx') ),
			'single_item_custom_field' => array('type' => 'text', 'name' => __('Custom field meta besides title in full view','gridfx'), 'help' => __('To display a custom field data besides the title, leave blank to disable.','gridfx'), 'default' => '', 'doc' => __('This can be a custom meta key that displays data besides the title such as price, or any other meta data needed. Leave blank to disable.','gridfx') ),
			'single_image_action' => array('type' => 'select', 'name' => __('When image is clicked in full view','gridfx'), 'values' => array( 'fancybox' => __('Open fancybox gallery','gridfx'), 'permalink' => __('Go to Post Permalink/URL','gridfx'), 'nothing' => __('Do Nothing with Image','gridfx') ), 'default' => 'fancybox', 'doc' => __('This will control the action that happens when they click the image under full view, this can be fancybox or permalink.','gridfx') ),
		);
		
		$this->fields['misc'] = array(
			'grid_image_size' => array('type' => 'select', 'name' => __('Optimal Image Size in Grid','gridfx'), 'values' => array( 'thumbnail' => 'thumbnail', 'medium' => 'medium', 'large' => 'large', 'full' => 'full'), 'help' => __('Choosing a smaller version of the image can improve your grid performance.','gridfx'), 'default' => 'large', 'doc' => __('The optimal image size to be considered in grid view display. This can be full, large, medium, or thumbnail. This can be decided based on grid width or number of items (columns).','gridfx') ),
			'single_image_size' => array('type' => 'select', 'name' => __('Optimal Image Size in Quick View','gridfx'), 'values' => array( 'thumbnail' => 'thumbnail', 'medium' => 'medium', 'large' => 'large', 'full' => 'full'), 'default' => 'large', 'doc' => __('The optimal image size to be considered in full view or quick mode display. This can be full, large, medium, or thumbnail. This is the optimal image size in full view.','gridfx') ),
			'placeholder' => array('type' => 'select', 'name' => __('Enable Placeholder','gridfx'), 'values' => gridfx_list_yes_or_no(), 'help' => __('An image placeholder is an image that will be displayed when no images are available for the post.','gridfx'), 'default' => 1, 'doc' => __('Enable or disable the image placeholder that gets displayed If your post does not have an image yet. This can be 1 or 0.','gridfx') ),
			'builtin_placeholder' => array('type' => 'select', 'name' => __('Builtin Placeholder to Use','gridfx'), 'values' => gridfx_list_files('images/placeholders', 'jpg'), 'default' => 'light', 'doc' => __('If you enable placeholders, you can choose which placeholder image to use here. examples: light or dark or image name.','gridfx') ),
			'custom_placeholder' => array('type' => 'text', 'name' => __('Custom Placeholder URL','gridfx'), 'help' => __('If you want another image as a placeholder, enter the full URL here.','gridfx'), 'default' => '', 'doc' => __('If you prefer to use your own placeholder, enter your custom placeholder image URL here or leave blank to use builtin placeholder.','gridfx') ),
			'loader_mini' => array('type' => 'text', 'name' => __('Mini Loading Image','gridfx'), 'help' => __('Enter the URL of small loading image/gif here.','gridfx'), 'default' => gridfx_url . 'images/loader_mini.gif', 'doc' => __('This is the URL of mini loading spinner that is used by the Grid FX plugin to update likes for example. Enter full URL here to change this image.','gridfx') ),
			'voting_duration'	=> array('type' => 'text', 'name' => __('No of days users can not vote','gridfx'), 'help' => __('You can specify number of days to avoid voting again.','gridfx'), 'default' => '7', 'doc' => __('','gridfx') ),
		);
		
		$this->fields['lightbox'] = array(
			'lightbox_background' => array('type' => 'text', 'name' => __('Lightbox Background','gridfx'), 'help' =>  __('Enter rgba color to control the background color of lightbox.','gridfx'), 'default' => '', 'doc' => __('This is the RGBa background color to use for fancybox/lightbox images as a background. examples: rgba(255, 255, 255, 0.80) Leave blank for default fancybox background.','gridfx') ),
			'lightbox_padding' => array('type' => 'text', 'name' => __('Padding','gridfx'), 'help' =>  __('Enter pixels number to control the padding inside lightbox images.','gridfx'), 'default' => 0, 'doc' => __('This controls the padding inside lightbox images. If you set this to 0, padding and borders in the lightbox will not be displayed.','gridfx') ),
			'lightbox_margin' => array('type' => 'text', 'name' => __('Margin','gridfx'), 'help' =>  __('Enter pixels number to control the margin outside lightbox images.','gridfx'), 'default' => 0, 'doc' => __('This controls the margin outside lightbox images. The distance from the image edges to screen edges.','gridfx') ),
			'lightbox_title' => array('type' => 'select', 'name' => __('Show Image Title','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('Enables or disables display of image title in the lightbox.','gridfx') ),
			'lightbox_title_type' => array('type' => 'select', 'name' => __('Title Position','gridfx'),
				'values' => array('float' => __('float','gridfx'), 'over' => __('over','gridfx'),'inside' => __('inside','gridfx'),'outside' => __('outside','gridfx') ), 'default' => 'float' , 'doc' => __('This is title type if you enable title in lightbox, you can set this to: over, inside, outside, or float. This will control the appearance of lightbox title.','gridfx') ),
			'lightbox_closeclick' => array('type' => 'select', 'name' => __('Close content on click','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('When enabled, lightbox content will be closed when user clicks on it. This option can be 1 or 0.','gridfx') ),
			'lightbox_closebtn' => array('type' => 'select', 'name' => __('Show Close Button','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('Shows or hides the close button in lightbox mode. This option can be 1 or 0.','gridfx') ),
			'lightbox_buttons' => array('type' => 'select', 'name' => __('Show Buttons','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('Shows or hides the lightbox buttons helper that helps you navigate between multiple images.','gridfx') ),
			'lightbox_thumbs' => array('type' => 'select', 'name' => __('Show Thumbnails','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 1, 'doc' => __('Shows or hides the small thumbnails that helps you browse photos in each post gallery.','gridfx') ),
		);
		
		$this->fields['woo'] = array(
			'taxonomy_filter_woo' => array('type' => 'multiselect', 'name' => __('Category Filters for WooCommerce','gridfx'), 'values' => gridfx_list_taxonomies_woo(1), 'placeholder' => __('Select taxonomies','gridfx'), 'default' => 'product_cat', 'doc' => __('You can use a comma seperated list of available WooCommerce taxonomies.','gridfx') ),
			'add_to_cart_choose' => array('type' => 'select', 'name' => __('Insert Add to cart button in gallery','gridfx'), 'values' => gridfx_list_yes_or_no(), 'default' => 0, 'doc' => __('When enabled, Add to cart button will be available in the gallery.','gridfx') ),
		);
		
		foreach($this->fields as $k => $array) {
			foreach($array as $subk => $subarray) {
				$this->defaults[$subk] = $subarray['default'];
			}
		}
				
		$this->options = get_option('gridfx');
		if (!get_option('gridfx')) {
			update_option('gridfx', $this->defaults);
		}

		$this->doc_faqs = array(
			
			__('What does Grid FX plugin do?','gridfx') => __('Grid FX plugin lets you create beautiful content walls on the fly using a grid or masonry layout. The content can be your posts, images, products, or any custom post type. Grid FX also lets you customize 70+ options and parameters for each wall to give you flexibility and customization.','gridfx'),
			
			__('Does this plugin support custom post types and taxonomies?','gridfx') => __('Yes. Grid FX includes options to customize the post types, and taxonomy/category filtering using isotope method.','gridfx'),
			
			__('How can I embed a Grid FX gallery to my post or page?','gridfx') => __('You can use the default shortcode markup: <code>[gridfx]</code> to include the plugin where shortcodes are supported. Also you can go to the <a href="?page=gridfx&tab=generate">Generate</a> panel to create a customized gallery or grid and get a lively updated markup instantly which you can use to show the gallery where you want.','gridfx'),
			
			__('How can I show media (video or audio) on the grid wall?','gridfx') => __('First make sure that you enabled Media under plugin Media settings. Then just enter the media URL in your post and the plugin will do the rest! example: <code>http://vimeo.com/22647358</code> <strong>YouTube, Vimeo, Dailymotion, MP4, FLV, or SoundCloud tracks are supported currently.</strong>','gridfx'),
			
			__('What is the difference between Settings and Generate pages?','gridfx') => __('The <strong>Settings</strong> page lets you edit the default settings or behaviour of your Grid FX plugin using the default shortcode <code>[gridfx]</code> however the <strong>Generate</strong> page lets you create customized Grid FX gallery instances instantly so you can have many Grid FX walls and each wall has its own settings, style, etc.','gridfx'),
			
			__('How can I link to the post permalink?','gridfx') => __('The plugin has 3 options to display custom links or buttons on your grid view or single view. They are: item_links, item_extended_links, or single_item_links. The easier option to link to your original post is by enabling <strong>Link to Post</strong> in your Grid or Single view settings and choose an appropriate option for the link. Also you can do this manually by passing your item_extended_links option: <code>post|Read full article</code> this will show a button to post permalink instantly. The markup for entering custom buttons in these 3 fields is like this: <code>post or metakey or URL|text to display|button style</code>. Multiple links or buttons can be seperated by commas. Another option to link to post permalink would be to edit the templates <strong>loop-single.php and/or single.php in your /templates</strong> folder. They are clean formatted html files so It is easy to add any custom stuff to it.','gridfx'),
			
			__('Can I publish more than one wall on single page?','gridfx') => __('Yes! Grid FX supports multiple walls on page without affecting each other. Because each instance has its own options and customization.','gridfx'),
			
			__('Where can I edit the template or HTML that is used to display the grid items?','gridfx') => __('Under <strong>templates</strong> folder you will find loop.php, loop-single.php and single.php these files are responsible for displaying the grid items or single item view. You can edit them directly, the HTML is clean and seperated from code which makes the plugin ultra flexible. In <strong>css.php</strong> file you can alter responsiveness, add some special css rules, and so on.','gridfx'),
			
			__('Does Grid FX has its own colors and themes?','gridfx') => __('Yes. Grid FX plugin has its own themes and styles to change the colors and look of your plugin. You can even use a different theme per each wall. To customize the color schemes or create new ones, simply go to <strong>templates/themes</strong> folder.','gridfx'),
			
			__('There are also themes under "single" folder. What are they for?','gridfx') => __('Grid FX plugin offers two types of themes. There are themes that control the general appearance of the grid view, and there are themes that control the appearance of single item when you expand an item details. This means you can have different style for grid view, and different style for single item or full view to give you maximum flexibility.','gridfx'),
			
			__('How can I change the grid background or other CSS?','gridfx') => __('You can edit the theme in use using any text editor and modify the CSS. The themes can be found in <strong>templates/themes</strong> folder. You can also create new themes and use them in your grid by customizing the theme option when you  <a href="?page=gridfx&tab=generate">generate</a> a new grid shortcode.','gridfx'),
			
			__('Where can I find or edit buttons styles and color schemes?','gridfx') => __('You can view/edit/add button styles by editing <strong>/css/gridfx-buttons.css</strong> file. You can see button themes in that file. Button themes are useful when creating custom button template in the shortcode.','gridfx'),
			
		);
		
	}
	
	function admin_head(){
		$screen = get_current_screen();
		$slug = $this->slug;
		$icon = gridfx_url . "admin/images/$slug-32.png";
		echo '<style type="text/css">';
			if (in_array( $screen->id, array( $slug ) ) || strstr($screen->id, $slug) ) {
				print "#icon-$slug {background: url('{$icon}') no-repeat left;}";
			}
		echo '</style>';
	}

	function add_styles(){

		wp_register_style( 'gridfx_admin', gridfx_url.'admin/css/admin.css');
		wp_enqueue_style('gridfx_admin');
		
		wp_register_script( 'gridfx_admin', gridfx_url.'admin/scripts/admin.js', array('jquery') );
		wp_enqueue_script( 'gridfx_admin' );
		
		wp_register_style('gridfx_chosen', gridfx_url.'admin/css/chosen.css');
		wp_enqueue_style('gridfx_chosen');
		
		wp_register_script('gridfx_chosen', gridfx_url.'admin/scripts/chosen.jquery.min.js');
		wp_enqueue_script('gridfx_chosen');
	
	}
	
	function add_menu() {
		add_menu_page( __('Grid FX','gridfx'), __('Grid FX','gridfx'), 'manage_options', $this->slug, array(&$this, 'admin_page'), gridfx_url .'admin/images/'.$this->slug.'-16.png');
	}

	function admin_tabs( $current = null ) {
			$tabs = $this->tabs;
			$links = array();
			if ( isset ( $_GET['tab'] ) ) {
				$current = $_GET['tab'];
			} else {
				$current = $this->default_tab;
			}
			foreach( $tabs as $tab => $name ) :
				if ( $tab == $current ) :
					$links[] = "<a class='nav-tab nav-tab-active' href='?page=".$this->slug."&tab=$tab'>$name</a>";
				else :
					$links[] = "<a class='nav-tab' href='?page=".$this->slug."&tab=$tab'>$name</a>";
				endif;
			endforeach;
			foreach ( $links as $link )
				echo $link;
	}

	function get_tab_content() {
		$screen = get_current_screen();
		if( strstr($screen->id, $this->slug ) ) {
			if ( isset ( $_GET['tab'] ) ) {
				$tab = $_GET['tab'];
			} else {
				$tab = $this->default_tab;
			}
			require_once gridfx_path.'admin/panels/'.$tab.'.php';
		}
	}
	
	function do_field($id, $field) {
		$type = $field['type'];
		
		if(isset($field['id']))
		$id = $field['id'];
		if(isset($field['values']))
		$values = $field['values'];
		if(isset($field['placeholder']))
			$placeholder = $field['placeholder'];
				switch($type){
						
					case 'text':
						echo "<input type='text' name='$id' id='$id' value='".gridfx_get_option($id)."' />";
						break;
						
					case 'radio':
						foreach($values as $k=>$v) {
							echo "<label class='gridfx-admin-radio'><span ";
							if (checked($k, gridfx_get_option($id),0)) { echo 'class="checked"'; }
							echo "></span><input type='radio' value='$k' name='$id'";
							checked($k, gridfx_get_option($id));
							echo " />$v</label>";
						}
						break;
						
					case 'select':
						if (isset($field['placeholder'])) {
							$placeholder = 'data-placeholder="'.$field['placeholder'].'"';
						} else {
							$placeholder = null;
						}
						echo "<select $placeholder name='$id' id='$id' class='chosen-select'>";
						foreach($values as $k=>$v) {
							echo "<option value='$k' ".selected($k, gridfx_get_option($id), 0).">$v</option>";
						}
						echo "</select>";
						break;
						
					case 'multiselect':
						if ($field['placeholder']) {
							$placeholder = 'data-placeholder="'.$field['placeholder'].'"';
						} else {
							$placeholder = null;
						}
						echo "<select $placeholder name='".$id.'[]'."' multiple='multiple' class='chosen-select'>";
						foreach($values as $k=>$v) {
							if (strstr($k, 'optgroup_b')) {
								echo "<optgroup label='$v'>";
							} elseif (strstr($k, 'optgroup_e')) {
								echo "</optgroup>";
							} else {
								echo "<option value='$k' ";
								if ( ( is_array(gridfx_get_option($id)) && in_array($k, gridfx_get_option($id)) ) || $k == gridfx_get_option($id) ) { echo 'selected="selected"'; }
								echo ">$v</option>";
							}
						}
						echo "</select>";
						break;
						
					case 'textarea':
						echo "<textarea name='$id' id='$id' rows='4' cols='50'>".stripslashes(gridfx_get_option($id))."</textarea>";
						break;
							
				}
				
	}
	
	function save() {
		/* fix multiselect fields */
		
		foreach($this->fields as $section => $array) {
			foreach($array as $sub => $subvalue) {
				if ($subvalue['type'] == 'multiselect') {
					$this->options[$sub] = 0;
				}
			}
		}
		foreach($_POST as $key => $value) {
			if ($key != 'submit') {
				if (!is_array($_POST[$key])) {
					$this->options[$key] = esc_attr($_POST[$key]);
				} else {
					$this->options[$key] = $_POST[$key];
				}
			}
		}
		update_option('gridfx', $this->options);
		echo '<div class="updated"><p><strong>'.__('Settings saved.','gridfx').'</strong></p></div>';
	}

	function reset() {
		update_option('gridfx', $this->defaults );
		$this->options = array_merge( $this->options, $this->defaults );
		echo '<div class="updated"><p><strong>'.__('Settings are reset to default.','gridfx').'</strong></p></div>';
	}

	function admin_page() {

		if (isset($_POST['submit'])) {
			$this->save();
		}

		if (isset($_POST['reset-options'])) {
			$this->reset();
		}
		
	?>
	
		<div class="wrap <?php echo $this->slug; ?>-admin">
			
			<div id="icon-<?php echo $this->slug; ?>" class="icon32"><br /></div><h2 class="nav-tab-wrapper"><?php $this->admin_tabs(); ?></h2>

			<div class="<?php echo $this->slug; ?>-admin-contain">
				
				<?php $this->get_tab_content(); ?>
				
				<div class="clear"></div>
				
			</div>
			
		</div>

	<?php }

}

$gridfx_admin = new gridfx_admin();
